@@ -86,7 +86,7 @@ class FeatureGenerator:
 
     def transform(self,fields_jsons):
         if isinstance(fields_jsons,pd.DataFrame):
-            return self.transform_for_dataframe(df_fields)
+            return self.transform_for_dataframe(fields_jsons)
         if not isinstance(fields_jsons,list):
             fields_jsons = [fields_jsons]
         features=[]
@@ -148,7 +148,7 @@ class FeatureGenerator:
             # data分箱
             binning = self.binning_dict.get(field_name)
             if binning:
-                df_in[field_name] = df_in[field_name].apply(lambda x: binning.transform(x))
+                df_in[field_name] = pd.cut(df_in[field_name], bins=binning.bins)
             # woe编码
             woe = self.woe_dict.get(field_name)
             if woe:
@@ -159,7 +159,7 @@ class FeatureGenerator:
         return features
 
     def preprocessing(self, df_fields):
-        return df_fields
+        return df_fields.fillna(self.missing)
 
     def get_binning_woe(self):
         field_woe = [woe.woe_info for woe in self.woe_dict.values()]
